@@ -5,7 +5,7 @@ jest.resetModules();
 const Immutable2 = require('../src/Immutable');
 
 describe('MultiRequire', () => {
-  it('might require two different instances of Immutable', () => {
+  it.skip('might require two different instances of Immutable', () => {
     expect(Immutable1).not.toBe(Immutable2);
     expect(Immutable1.Map({ a: 1 }).toJS()).toEqual({ a: 1 });
     expect(Immutable2.Map({ a: 1 }).toJS()).toEqual({ a: 1 });
