@@ -120,7 +120,8 @@ export class Record {
 
   equals(other) {
     return (
-      this === other || (other && recordSeq(this).equals(recordSeq(other)))
+      this === other ||
+      (isRecord(other) && recordSeq(this).equals(recordSeq(other)))
     );
   }
 
