@@ -23,7 +23,7 @@ import isArrayLike from './utils/isArrayLike';
 
 export class Seq extends Collection {
   constructor(value) {
-    return value === null || value === undefined
+    return value === undefined || value === null
       ? emptySequence()
       : isImmutable(value)
       ? value.toSeq()
@@ -85,7 +85,7 @@ export class Seq extends Collection {
 
 export class KeyedSeq extends Seq {
   constructor(value) {
-    return value === null || value === undefined
+    return value === undefined || value === null
       ? emptySequence().toKeyedSeq()
       : isCollection(value)
       ? isKeyed(value)
@@ -103,7 +103,7 @@ export class KeyedSeq extends Seq {
 
 export class IndexedSeq extends Seq {
   constructor(value) {
-    return value === null || value === undefined
+    return value === undefined || value === null
       ? emptySequence()
       : isCollection(value)
       ? isKeyed(value)
@@ -191,7 +191,9 @@ export class ArraySeq extends IndexedSeq {
 
 class ObjectSeq extends KeyedSeq {
   constructor(object) {
-    const keys = Object.keys(object);
+    const keys = Object.keys(object).concat(
+      Object.getOwnPropertySymbols ? Object.getOwnPropertySymbols(object) : []
+    );
     this._object = object;
     this._keys = keys;
     this.size = keys.length;
