@@ -759,7 +759,7 @@ function getDoc(node: ts.Node): TypeDoc | undefined {
     .text.substring(trivia.pos, trivia.end)
     .split('\n')
     .slice(1, -1)
-    .map(l => l.trim().substr(2));
+    .map(l => l.trim().slice(2));
 
   const paragraphs = lines
     .filter(l => l[0] !== '@')
